# The So-What
*consultify* allows users to convert pandas DataFrames into PowerPoint slides, following the conventions of a McKinsey Marvin Table.

# Installation
```
pip install consultify
```

# Usage
```
from consultify.consultify import marvintable
marvintable(df)
```

# #plsfix
Email ryu@mba2021.hbs.edu for feedback.